searchData={"items":[{"type":"module","title":"RememberMe","doc":"RememberMe is a robust but simple state memory machine organizer. you can assimilate it like a Redis, but the difference is that you can schedule and define the number of times a function will be executed and of course save any values ​​from an assimilated key.","ref":"RememberMe.html"},{"type":"module","title":"Installation - RememberMe","doc":"RememberMe can be installed by adding it as a dependency in your `mix.exs`\nfile:\n\n```elixir\ndefp deps do\n  [\n    {:remember_me, \"~> 0.0.1\"}\n  ]\nend\n```","ref":"RememberMe.html#module-installation"},{"type":"module","title":"Examples - RememberMe","doc":"iex> RememberMe.guard(\"text_deleted\", %{\"user\" => \"Foo\", \"text\" => \"A any message\"}, min: 2)\n  :ok\n\n  iex> RememberMe.find_value(\"text_deleted\")\n  %{\n    \"user\" => \"Foo\",\n    \"text\" => \"A any message\"\n  }\n\n  iex> RememberMe.exec_func(fn -> IO.puts \"Hello World!\" end, [sec: 10, repeat: 3])\n  :ok\n  Hello World!\n\n  20:13:59.336 [info] Started execute function\n  Hello World!\n  Hello World!\n  20:14:29.342 [info] Finish Execute function\n  iex>\n\n\n  Important to note that if no opts are passed, the default value for time will be 3 minutes and the repeat will default to 1 time.","ref":"RememberMe.html#module-examples"},{"type":"function","title":"RememberMe.exec_func/2","doc":"will queue a specified amount of functions in memory to be executed in the given time","ref":"RememberMe.html#exec_func/2"},{"type":"function","title":"Parameters - RememberMe.exec_func/2","doc":"- fun: Function that will executed\n  - opts: Sets a time to stay in memory, can be sec, min or hour - default: 3 minutes and defines the number of times the function should be repeated, default is 1","ref":"RememberMe.html#exec_func/2-parameters"},{"type":"function","title":"Examples - RememberMe.exec_func/2","doc":"iex> RememberMe.exec_func(fn -> IO.puts \"Hello World!\" end, [sec: 10, repeat: 3])\n  :ok\n  Hello World!\n\n  20:13:59.336 [info] Started execute function\n  Hello World!\n  Hello World!\n  20:14:29.342 [info] Finish Execute function\n  iex>","ref":"RememberMe.html#exec_func/2-examples"},{"type":"function","title":"RememberMe.find_value/1","doc":"Will get value saved in memory from key","ref":"RememberMe.html#find_value/1"},{"type":"function","title":"Parameters - RememberMe.find_value/1","doc":"- name_state: String that represents the name of the key.","ref":"RememberMe.html#find_value/1-parameters"},{"type":"function","title":"Examples - RememberMe.find_value/1","doc":"iex> RememberMe.find_value(\"text_deleted\")\n  %{\n    \"user\" => \"Foo\",\n    \"text\" => \"A any message\"\n  }","ref":"RememberMe.html#find_value/1-examples"},{"type":"function","title":"RememberMe.guard/3","doc":"Will save a value in RAM memory with a key to get it later","ref":"RememberMe.html#guard/3"},{"type":"function","title":"Parameters - RememberMe.guard/3","doc":"- name_state: String that represents the name of the key.\n  - value: Any value\n  - opts: Sets a time to stay in memory, can be sec, min or hour - default: 3 minutes","ref":"RememberMe.html#guard/3-parameters"},{"type":"function","title":"Examples - RememberMe.guard/3","doc":"iex> RememberMe.guard(\"text_deleted\", %{\"user\" => \"Foo\", \"text\" => \"A any message\"}, min: 2)\n    :ok\n\n    iex> RememberMe.guard(\"text_deleted\", %{\"user\" => \"Foo\", \"text\" => \"Another message\"}, min: 2)\n    :ok\n\n\nNote that if you pass a key equal to the previous one to the guard(), it will simply replace the value with the current value.","ref":"RememberMe.html#guard/3-examples"},{"type":"macro","title":"RememberMe.validate_params_fun/2","doc":"","ref":"RememberMe.html#validate_params_fun/2"},{"type":"macro","title":"RememberMe.validate_params_guard/3","doc":"","ref":"RememberMe.html#validate_params_guard/3"}],"content_type":"text/markdown"}